@@ -5,20 +5,6 @@ sub pfact {
     my ( $p ) = shift->{'pfact'};
 
     for ( $p->{'kernel'} ) {
-        /AIX/ && do {
-            if ( -e '/usr/sbin/lsattr' ) {
-                open ( F, '/usr/sbin/lsattr -l sys0 -E -a modelname 2>/dev/null |' );
-                my ( @F ) = <F>;
-                close( F );
-
-                foreach ( @F ) {
-                    if ( /modelname\s.*,(.*)\sMachine/ ) {
-                        return $1;
-                    }
-                }
-            }
-        };
-
         /Linux/ && do {
             if ( -e '/usr/sbin/dmidecode' ) {
                 my ( $f );
@@ -48,6 +34,16 @@ sub pfact {
             }
         };
 
+        /SunOS/ && do {
+            if ( -e '/usr/bin/uname' ) {
+                chomp( my $r = qx( /bin/uname -i ) );
+
+                if ( $r =~ /^.+?,(.*)$/ ) {
+                    return $1;
+                }
+            }
+        };
+
         return qq((kernel not supported));
     }
 }
